@@ -1,6 +1,6 @@
 use clap::StructOpt;
 use lunes::{
-    node::exec::{config, down, install, logs, status, up, version, restart},
+    node::exec::{config, down, install, logs, restart, status, up, version},
     node::NodeCommands,
     wallet::WalletCommands,
     Cli, Commands,
@@ -13,7 +13,7 @@ fn main() {
 
     match args.command {
         Commands::Node(subcommand) => match subcommand.command.unwrap_or(NodeCommands::Version) {
-            NodeCommands::Install(arg) => install(arg.version),
+            NodeCommands::Install(args) => install(args),
             NodeCommands::Version => version(),
             NodeCommands::Restart => restart(),
             NodeCommands::Config => config(),
