@@ -5,7 +5,8 @@ use super::utils::{mount_hocon, mount_service};
 
 #[cfg(target_os = "linux")]
 pub fn up() {
-    println!("Up Lunes Node");
+    std::process::Command::new("clear").status().unwrap();
+    println!("🛫 Up Lunes Node");
 
     match Command::new("systemctl")
         .arg("start")
@@ -15,11 +16,13 @@ pub fn up() {
         Err(e) => panic!("Error starting Lunes Node, {:?}", e),
         Ok(x) => x,
     };
+    println!("✅ Done!");
 }
 
 #[cfg(target_os = "linux")]
 pub fn down() {
-    println!("Down Lunes Node");
+    std::process::Command::new("clear").status().unwrap();
+    println!("🛬 Down Lunes Node");
 
     match Command::new("systemctl")
         .arg("stop")
@@ -29,11 +32,13 @@ pub fn down() {
         Err(e) => panic!("Error stopping Lunes Node, {:?}", e),
         Ok(x) => x,
     };
+    println!("✅ Done!");
 }
 
 #[cfg(target_os = "linux")]
 pub fn logs() {
-    println!("Logs Lunes Node");
+    std::process::Command::new("clear").status().unwrap();
+    println!("📊 Logs Lunes Node");
 
     match Command::new("journalctl")
         .arg("-fu")
@@ -43,11 +48,13 @@ pub fn logs() {
         Err(e) => panic!("Error show Lunes Node Logs, {:?}", e),
         Ok(x) => x,
     };
+    println!("✅ Done!");
 }
 
 #[cfg(target_os = "linux")]
 pub fn status() {
-    println!("Status Lunes Node");
+    std::process::Command::new("clear").status().unwrap();
+    println!("🌡  Status Lunes Node");
 
     match Command::new("systemctl")
         .arg("status")
@@ -57,11 +64,14 @@ pub fn status() {
         Err(e) => panic!("Error read status of Lunes Node, {:?}", e),
         Ok(x) => x,
     };
+    println!("✅ Done!");
 }
 
 #[cfg(target_os = "linux")]
 pub fn restart() {
-    println!("Restart Lunes Node");
+        std::process::Command::new("clear").status().unwrap();std::process::Command::
+    new("clear").status().unwrap();
+    println!("✈️  Restart Lunes Node");
 
     match Command::new("systemctl")
         .arg("restart")
@@ -71,6 +81,7 @@ pub fn restart() {
         Err(e) => panic!("Error restarting Lunes Node, {:?}", e),
         Ok(x) => x,
     };
+    println!("✅ Done!");
 }
 
 pub fn version() {
@@ -90,33 +101,45 @@ pub fn install(args: NodeInstall) {
     match args.version {
         Some(v) => match v.as_str() {
             "0.0.7" => {
-                println!("Downloading Lunes Node ...");
+                std::process::Command::new("clear").status().unwrap();
+                println!("⬇️  Downloading Lunes Node ...");
                 Command::new("wget")
                 .args(["-O", "/opt/lunesnode/lunesnode.jar"])
                 .arg("https://github.com/lunes-platform/lunes-node/releases/download/0.0.7/lunesnode.jar")
-                .output()
+                .output();
+                println!("✅ Done!");
+                println!("🚀 Running `lunes node up` to start");
             },
             "0.1.0" => {
-                println!("Downloading Lunes Node ...");
+                std::process::Command::new("clear").status().unwrap();
+                println!("⬇️  Downloading Lunes Node ...");
                 Command::new("wget")
                 .args(["-O", "/opt/lunesnode/lunesnode.jar"])
                 .arg("https://github.com/lunes-platform/lunes-node/releases/download/0.1.0/lunesnode.jar")
-                .output()
+                .output();
+                println!("✅ Done!");
+                println!("🚀 Running `lunes node up` to start");
             },
             _ => {
-                println!("Downloading Lunes Node ...");
+                std::process::Command::new("clear").status().unwrap();
+                println!("⬇️  Downloading Lunes Node ...");
                 Command::new("wget")
                 .args(["-O", "/opt/lunesnode/lunesnode.jar"])
                 .arg("https://github.com/lunes-platform/lunes-node/releases/download/0.1.0/lunesnode.jar")
-                .output()
+                .output();
+                println!("✅ Done!");
+                println!("🚀 Running `lunes node up` to start");
             }
         },
         None => {
-            println!("Downloading Lunes Node ...");
+            std::process::Command::new("clear").status().unwrap();
+            println!("⬇️  Downloading Lunes Node ...");
             Command::new("wget")
             .args(["-O", "/opt/lunesnode/lunesnode.jar"])
             .arg("https://github.com/lunes-platform/full-node/releases/download/0.1.0/lunesnode.jar")
-            .output()
+            .output();
+            println!("✅ Done!");
+            println!("🚀 Running `lunes node up` to start");
         }
     };
 }
